@@ -18,7 +18,7 @@ class GSCNodeFunctionReceiverSocket:
 
         @self.sio.event
         async def oncnodefunction(id, msg):
-            self.oncnodefunction(id, msg)
+            self.oncnodefunction(self.gsdbs, id, msg)
 
         connectURL = ""
 
