@@ -86,9 +86,9 @@ class GSPeerConnectionWatcher:
                         blackHole.addTrack(mediaTrack)
                         await blackHole.start()
 
-                @track.on("ended")
-                async def on_ended():
-                    self.ontrackended(self.gsdbs, self.target)
+                # @track.on("ended")
+                # async def on_ended():
+                #     await self.ontrackended(self.gsdbs, self.target)
 
             await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
             await self.sio.emit("watcher",
@@ -98,14 +98,16 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def answer(id, description):
-
             if isinstance(description, dict):
                 desc = type('new_dict', (object,), description)
             else:
                 desc = type('new_dict', (object,), ast.literal_eval(description))
-
             await self.peerConnections.setRemoteDescription(desc)
 
+        @self.sio.event
+        async def disconnectBroadcaster(id, target):
+            await self.ontrackended(self.gsdbs, target)
+
         if "localhost" in self.gsdbs.credentials["signalserver"]:
             connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
         else:
